# License : The libraries are BSD license. The command line interface programs (lz4.exe, fullbench, fuzzer, datagen) are GPLv2. 
%global _hardened_build 1

Name:           lz4
Version:        r120
Release:        1%{?dist}
Summary:        Extremely fast compression algorithm

Group:          Applications/System
License:        GPLv2
URL:            https://code.google.com/p/lz4/
Source0:        https://github.com/Cyan4973/lz4/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:		lz4.cflags.patch
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%description
LZ4 is an extremely fast loss-less compression algorithm, providing compression
speed at 400 MB/s per core, scalable with multi-core CPU. It also features
an extremely fast decoder, with speed in multiple GB/s per core, typically
reaching RAM speed limits on multi-core systems.

%package        devel
Summary:        Development library for lz4
Group:          Development/Libraries
License:        BSD
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description    devel
This package contains the header files required to build
applications using liblz4 library.

%package        libs
Summary:        Libraries for lz4 compression
Group:          System Environment/Libraries
License:        BSD

%description    libs
Libraries for dealing with files with lz4 compression.

%package        static
Summary:        Static library for lz4
Group:          Development/Libraries
License:        BSD

%description    static
LZ4 is an extremely fast loss-less compression algorithm. This package contains 
static libraries needed for static linking of applications using liblz4.


%prep
%setup -q
%patch0 -b .cflags

%build
if [ ! -f configure ] ; then
        # Hack to place CFLAGS, etc. into the environment
        echo "#!/bin/sh
        exec /bin/true" > configure
        chmod 0755 configure
fi
%configure
make V=1 %{?_smp_mflags}


%install
rm -fR $RPM_BUILD_ROOT
make V=1 DESTDIR="$RPM_BUILD_ROOT" PREFIX=%{_prefix} LIBDIR=%{_libdir} INCLUDEDIR=%{_includedir} install


%check
make test

%clean
rm -fR $RPM_BUILD_ROOT

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig


%files
%defattr (-, root, root, -)
%doc programs/COPYING NEWS
%{_bindir}/lz4
%{_bindir}/lz4c
%{_bindir}/lz4cat
%{_mandir}/man1/lz4*

%files devel
%defattr (-, root, root, -)
%{_includedir}/*.h
%{_libdir}/liblz4.so
%{_libdir}/pkgconfig/liblz4.pc

%files libs
%defattr (-, root, root, -)
%doc LICENSE NEWS
%{_libdir}/liblz4.so.*

%files static
%defattr (-, root, root, -)
%doc LICENSE NEWS
%{_libdir}/liblz4.a


%changelog
* Mon Jul 28 2014 Japheth Cleaver <cleaver@terabithia.org> - r120-1
- new release r120
- add %%check block
- enable use of %%configure macro
- remove docs from devel subpackage
- move ldconfig to libs subpackage
- move pkgconfig file to devel subpackage
- move base object symlink from libs to devel subpackge

* Mon Jul 07 2014 Japheth Cleaver <cleaver@terabithia.org> - r119-1
- new release r119
- specify architecture in requires

* Mon Jun 30 2014 Japheth Cleaver <cleaver@terabithia.org> - r118-1
- new release r118
- Move shared lib to main package
- Add lz4-static package

* Sat Jun 14 2014 pjp <pjp@fedoraproject.org> - r117-3
- Move shared library object to -devel package.

* Sat Jun 07 2014 pjp <pjp@fedoraproject.org> - r117-2
- Skip static library from installation.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - r117-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Jun 06 2014 pjp <pjp@fedoraproject.org> - r117-1
- new release
- added lz4c & lz4cat manual pages.

* Sun Apr 13 2014 pjp <pjp@fedoraproject.org> - r116-1
- new release 116
- added lz4cat utility for posix systems

* Sat Mar 15 2014 pjp <pjp@fedoraproject.org> - r114-1
- new release r114
- added RPM_OPT_FLAGS to CFLAGS
- introduced a devel package to build liblz4

* Thu Jan 02 2014 pjp <pjp@fedoraproject.org> - r110-1
- new release r110

* Sun Nov 10 2013 pjp <pjp@fedoraproject.org> - r108-1
- new release r108

* Wed Oct 23 2013 pjp <pjp@fedoraproject.org> - r107-1
- new release r107

* Mon Oct 07 2013 pjp <pjp@fedoraproject.org> - r106-3
- fixed install section to replace /usr/ with a macro.
  -> https://bugzilla.redhat.com/show_bug.cgi?id=1015263#c5

* Sat Oct 05 2013 pjp <pjp@fedoraproject.org> - r106-2
- fixed install section above as suggested in the review.
  -> https://bugzilla.redhat.com/show_bug.cgi?id=1015263#c1

* Sun Sep 22 2013 pjp <pjp@fedoraproject.org> - r106-1
- Initial RPM release of lz4-r106
